@@ -2,7 +2,6 @@
 #
 # SPDX-License-Identifier: MIT
 
-import time
 import gc
 import math
 from machine import Pin, SPI
@@ -28,7 +27,3 @@ y = [constant * math.exp((-(_**2)) / 2.0) for _ in x]
 my_log = Logging(plot, x, y, rangex=[-4, 4], rangey=[0, 1], line_color=(255, 255, 0))
 
 display.show()
-time.sleep(1)
-
-my_log.update(plot)
-display.show()
